Welcome to django-lastfm’s documentation! — django-lastfm v0.1 documentation

### Navigation

- index
- modules |
- next |
- django-lastfm v0.1 documentation »

# Welcome to django-lastfm’s documentation!

Contents:

- Quickstart Guide
  - Get a Last.fm API key
  - Installation
  - Setup
  - Configuration
  - Add the widget to your templates
  - A word on caching
  - That’s it!
- API-Reference
  - Template Tags
  - Views

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- django-lastfm v0.1 documentation »